@@ -11,23 +11,31 @@ use crate::windowclass::WindowClass;
 // Default
 
 #[cfg(windows)]
+#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
 pub const DEFAULT_WINDOW_WIDTH: i32 = 1280;
 #[cfg(linux)]
+#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
 pub const DEFAULT_WINDOW_WIDTH: i32 = 1280;
 
 #[cfg(windows)]
+#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
 pub const DEFAULT_WINDOW_HEIGHT: i32 = 720;
 #[cfg(linux)]
+#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
 pub const DEFAULT_WINDOW_HEIGHT: i32 = 1280;
 
 #[cfg(windows)]
+#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
 pub const DEFAULT_WINDOW_X: i32 = 500;
 #[cfg(linux)]
+#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
 pub const DEFAULT_WINDOW_X: i32 = 1280;
 
 #[cfg(windows)]
+#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
 pub const DEFAULT_WINDOW_Y: i32 = 500;
 #[cfg(linux)]
+#[deprecated(since="0.2.2", note="Please enter the values manually instead.")]
 pub const DEFAULT_WINDOW_Y: i32 = 1280;
 
 // Button Styles
@@ -77,7 +85,7 @@ pub const DIALOGSTYLE_NONE: MessageType = gtk::MessageType::Other;
 #[cfg(windows)]
 pub const DIALOGSTYLE_INFO: MESSAGEBOX_STYLE = 64u32;
 #[cfg(linux)]
-pub const DIALOGSTYLE_NONE: MessageType = gtk::MessageType::Info;
+pub const DIALOGSTYLE_INFO: MessageType = gtk::MessageType::Info;
 
 #[cfg(windows)]
 pub const DIALOGSTYLE_QUESTION: MESSAGEBOX_STYLE = 32u32;
@@ -85,14 +93,21 @@ pub const DIALOGSTYLE_QUESTION: MESSAGEBOX_STYLE = 32u32;
 pub const DIALOGSTYLE_NONE: MessageType = gtk::MessageType::Question;
 
 #[cfg(windows)]
+#[deprecated(since="0.2.2", note="Please use DIALOGSTYLE_WARN instead.")]
 pub const DIALOGSTYLE_EXCLAMATION: MESSAGEBOX_STYLE = 48u32;
 #[cfg(linux)]
-pub const DIALOGSTYLE_NONE: MessageType = gtk::MessageType::Warning;
+#[deprecated(since="0.2.2", note="Please use DIALOGSTYLE_WARN instead.")]
+pub const DIALOGSTYLE_EXCLAMATION: MessageType = gtk::MessageType::Warning;
+
+#[cfg(windows)]
+pub const DIALOGSTYLE_WARN: MESSAGEBOX_STYLE = 48u32;
+#[cfg(linux)]
+pub const DIALOGSTYLE_WARN: MessageType = gtk::MessageType::Warning;
 
 #[cfg(windows)]
 pub const DIALOGSTYLE_ERROR: MESSAGEBOX_STYLE = 16u32;
 #[cfg(linux)]
-pub const DIALOGSTYLE_NONE: MessageType = gtk::MessageType::ERROR;
+pub const DIALOGSTYLE_ERROR: MessageType = gtk::MessageType::ERROR;
 
 // Dialog hints
 
