@@ -57,24 +57,27 @@ impl MessageBox {
     #[cfg(windows)]
     pub fn show(
         &self,
-        button_type: MESSAGEBOX_STYLE,
+        button_style: MESSAGEBOX_STYLE,
         dialog_style: MESSAGEBOX_STYLE,
-        window_style: u64,
-    ) {
+        dialog_hint: u64,
+    ) -> i32{
         use windows_sys::{
             Win32::Foundation::*, Win32::System::Threading::*, Win32::UI::WindowsAndMessaging::*,
         };
         unsafe {
             let event = CreateEventW(std::ptr::null(), 1, 0, std::ptr::null());
             SetEvent(event);
+            println!("{}",event);
             WaitForSingleObject(event, 0);
             CloseHandle(event);
-            MessageBoxA(
-                window_style.try_into().unwrap(),
+            let result = MessageBoxA(
+                dialog_hint.try_into().unwrap(),
                 self.message.as_ptr(),
                 self.title.as_ptr(),
-                dialog_style | button_type,
+                dialog_style | button_style,
             );
+            println!("{}",result);
+            return result;
         }
     }
 }
@@ -123,9 +126,9 @@ impl MessageBox {
     /// ```
     pub fn show(
         &self,
-        button_type: ButtonsType,
+        button_style: ButtonsType,
         dialog_style: MessageType,
-        window_style: DialogFlags,
+        dialog_hint: DialogFlags,
     ) {
         use gtk::prelude::*;
         let dialog = gtk::MessageDialog::new(
